package com.aucma.production.service;

import java.util.List;

import com.aucma.production.domain.ProdStationCapability;

public interface IProdStationCapabilityService {
    ProdStationCapability selectProdStationCapabilityByObjId(Long objId);

    List<ProdStationCapability> selectProdStationCapabilityList(ProdStationCapability prodStationCapability);

    int insertProdStationCapability(ProdStationCapability prodStationCapability);

    int updateProdStationCapability(ProdStationCapability prodStationCapability);

    int deleteProdStationCapabilityByObjIds(Long[] objIds);
}
