package com.aucma.production.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.aucma.common.annotation.Log;
import com.aucma.common.core.controller.BaseController;
import com.aucma.common.core.domain.AjaxResult;
import com.aucma.common.enums.BusinessType;
import com.aucma.production.domain.ProdStationCapability;
import com.aucma.production.service.IProdStationCapabilityService;
import com.aucma.common.utils.poi.ExcelUtil;
import com.aucma.common.core.page.TableDataInfo;

@RestController
@RequestMapping("/production/stationCapability")
public class ProdStationCapabilityController extends BaseController {
    @Autowired
    private IProdStationCapabilityService prodStationCapabilityService;

    @PreAuthorize("@ss.hasPermi('production:stationCapability:list')")
    @GetMapping("/list")
    public TableDataInfo list(ProdStationCapability prodStationCapability) {
        startPage();
        List<ProdStationCapability> list = prodStationCapabilityService.selectProdStationCapabilityList(prodStationCapability);
        return getDataTable(list);
    }

    @PreAuthorize("@ss.hasPermi('production:stationCapability:export')")
    @Log(title = "工位能力维护", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, ProdStationCapability prodStationCapability) {
        List<ProdStationCapability> list = prodStationCapabilityService.selectProdStationCapabilityList(prodStationCapability);
        ExcelUtil<ProdStationCapability> util = new ExcelUtil<ProdStationCapability>(ProdStationCapability.class);
        util.exportExcel(response, list, "工位能力维护数据");
    }

    @PreAuthorize("@ss.hasPermi('production:stationCapability:query')")
    @GetMapping(value = "/{objId}")
    public AjaxResult getInfo(@PathVariable("objId") Long objId) {
        return success(prodStationCapabilityService.selectProdStationCapabilityByObjId(objId));
    }

    @PreAuthorize("@ss.hasPermi('production:stationCapability:add')")
    @Log(title = "工位能力维护", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody ProdStationCapability prodStationCapability) {
        prodStationCapability.setCreatedBy(getUsername());
        return toAjax(prodStationCapabilityService.insertProdStationCapability(prodStationCapability));
    }

    @PreAuthorize("@ss.hasPermi('production:stationCapability:edit')")
    @Log(title = "工位能力维护", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody ProdStationCapability prodStationCapability) {
        prodStationCapability.setUpdatedBy(getUsername());
        return toAjax(prodStationCapabilityService.updateProdStationCapability(prodStationCapability));
    }

    @PreAuthorize("@ss.hasPermi('production:stationCapability:remove')")
    @Log(title = "工位能力维护", businessType = BusinessType.DELETE)
    @DeleteMapping("/{objIds}")
    public AjaxResult remove(@PathVariable Long[] objIds) {
        return toAjax(prodStationCapabilityService.deleteProdStationCapabilityByObjIds(objIds));
    }
}
